@@ -16,6 +16,7 @@ except ImportError:
 
 from robot.libraries.BuiltIn import BuiltIn, RobotNotRunningError
 
+from RPA.Cloud.objects import TextractDocument
 from RPA.Robocloud.Secrets import Secrets
 from RPA.RobotLogListener import RobotLogListener
 from RPA.Tables import Tables
@@ -358,14 +359,33 @@ class ServiceTextract(AWSBase):
 
     @aws_dependency_required
     def analyze_document(
-        self, image_file: str = None, json_file: str = None, bucket_name: str = None
+        self,
+        image_file: str = None,
+        json_file: str = None,
+        bucket_name: str = None,
+        model: bool = False,
     ) -> bool:
         """Analyzes an input document for relationships between detected items
 
         :param image_file: filepath (or object name) of image file
         :param json_file: filepath to resulting json file
         :param bucket_name: if given then using `image_file` from the bucket
-        :return: analysis response in json
+        :param model: set `True` to return Textract Document model, default `False`
+        :return: analysis response in json or TextractDocument model
+
+        Example:
+
+        .. code-block:: robotframework
+
+            ${response}    Analyze Document    ${filename}    model=True
+            FOR    ${page}    IN    @{response.pages}
+                Log Many    ${page.tables}
+                Log Many    ${page.form}
+                Log Lines    ${page.lines}
+                Log Many    ${page}
+                Log    ${page}
+                Log    ${page.form}
+            END
         """
         client = self._get_client_for_service("textract")
         if bucket_name:
@@ -383,7 +403,7 @@ class ServiceTextract(AWSBase):
         if json_file:
             with open(json_file, "w") as f:
                 json.dump(response, f)
-        return response
+        return self.convert_textract_response_to_model(response) if model else response
 
     def _parse_response_blocks(self, response):
         if "Blocks" not in response:
@@ -445,23 +465,23 @@ class ServiceTextract(AWSBase):
             self.tables[idx] = table
 
     def get_tables(self):
-        """[summary]
+        """Get parsed tables from the response
 
-        :return: [description]
+        :return: tables
         """
         return self.tables
 
     def get_words(self):
-        """[summary]
+        """Get parsed words from the response
 
-        :return: [description]
+        :return: words
         """
         return self.words
 
     def get_cells(self):
-        """[summary]
+        """Get parsed cells from the response
 
-        :return: [description]
+        :return: cells
         """
         return self.cells
 
@@ -667,6 +687,48 @@ class ServiceTextract(AWSBase):
         response = client.get_document_text_detection(**method_arguments)
         return response
 
+    def convert_textract_response_to_model(self, response):
+        """Convert AWS Textract JSON response into TextractDocument object,
+        which has following structure:
+
+            - Document
+            - Page
+            - Tables
+            - Rows
+            - Cells
+            - Lines
+            - Words
+            - Form
+            - Field
+
+        :param response: JSON response from AWS Textract service
+        :return: `TextractDocument` object
+
+        Example:
+
+        .. code-block:: robotframework
+
+            ${response}    Analyze Document    ${filename}
+            ${model}=    Convert Textract Response To Model    ${response}
+            FOR    ${page}    IN    @{model.pages}
+                Log Many    ${page.tables}
+                Log Many    ${page.form}
+                Log Lines    ${page.lines}
+                Log Many    ${page}
+                Log    ${page}
+                Log    ${page.form}
+            END
+        """
+        doc = None
+        try:
+            doc = TextractDocument(response)
+            self.logger.info(response.keys())
+        except Exception as e:  # pylint: disable=broad-except
+            self.logger.warning(
+                "Textract response could not be converted into model: %s", str(e)
+            )
+        return doc
+
 
 class ServiceComprehend(AWSBase):
     """Class for AWS Comprehend service"""
